/* This file was generated by syncqt. */
#ifndef QT_QTXMLPATTERNS_VERSION_H
#define QT_QTXMLPATTERNS_VERSION_H

#define QTXMLPATTERNS_VERSION_STR "5.15.17"

#define QTXMLPATTERNS_VERSION 0x050F11

#endif // QT_QTXMLPATTERNS_VERSION_H
